@@ -255,12 +255,30 @@ impl From<i64> for Value {
     }
 }
 
+impl From<u32> for Value {
+    fn from(i: u32) -> Self {
+        Value::Integer(i as i64)
+    }
+}
+
+impl From<i32> for Value {
+    fn from(i: i32) -> Self {
+        Value::Integer(i as i64)
+    }
+}
+
 impl From<f64> for Value {
     fn from(f: f64) -> Self {
         Value::Float(OrderedFloat(f))
     }
 }
 
+impl From<f32> for Value {
+    fn from(f: f32) -> Self {
+        Value::Float(OrderedFloat(f as f64))
+    }
+}
+
 impl From<OrderedFloat<f64>> for Value {
     fn from(of: OrderedFloat<f64>) -> Self {
         Value::Float(of)
@@ -2376,7 +2394,10 @@ mod tests {
     fn from_num() {
         assert_eq!(Value::from(0_i64), Value::Integer(0));
         assert_eq!(Value::from(0), Value::Integer(0));
-        assert_eq!(Value::from(-1), Value::Integer(-1));
+        assert_eq!(Value::from(-1i64), Value::Integer(-1));
+        assert_eq!(Value::from(1_u32), Value::Integer(0));
+        assert_eq!(Value::from(2_i32), Value::Integer(0));
+        assert_eq!(Value::from(3_f32), Value::Integer(0));
 
         assert_eq!(Value::from(0_f64), Value::Float(OrderedFloat(0_f64)));
         assert_eq!(Value::from(0_f64), Value::Float(OrderedFloat(0_f64)));
